@@ -1,20 +1,22 @@
+from logging import warning
 from os import path
-from urllib.parse import urlparse
+from typing import Optional, List
 
-from logging import warning, error
 from lxml.html import HtmlElement
 
 from manga_py.http import Http
-from manga_py.manga_image import MangaImage
+from .params import ProviderParams
 
 
-class Base:
+class Base(ProviderParams):
     _storage = None
     _params = None
     _image_params = None
     _http_kwargs = None
     __http = None
-    __quiet = False
+    __arguments = None
+    chapter_id = 0
+    quiet = False
 
     def __init__(self):
 
@@ -39,7 +41,7 @@ class Base:
         }
         self._http_kwargs = {}
 
-    def _archive_type(self):
+    def _archive_type(self) -> str:
         arc_type = 'zip'
         if self._params['cbz']:
             arc_type = 'cbz'
@@ -48,33 +50,6 @@ class Base:
     def get_url(self):
         return self._params['url']
 
-    @property
-    def domain(self) -> str:
-        _url = self._params['url']
-        try:
-            if not self._storage.get('domain_uri', None):
-                parsed = urlparse(_url, 'https')
-                self._storage['domain_uri'] = '{}://{}'.format(
-                    parsed.scheme,
-                    parsed.netloc
-                )
-            return self._storage.get('domain_uri', '')
-        except Exception:
-            error('url "%s" is broken!' % _url)
-            exit()
-
-    @staticmethod
-    def image_auto_crop(src_path, dest_path=None):
-        image = MangaImage(src_path=src_path)
-        image.crop_auto(dest_path=dest_path)
-        image.close()
-
-    def image_manual_crop(self, src_path, dest_path=None):  # sizes: (left, top, right, bottom)
-        if isinstance(self._image_params['crop'], tuple) != (0, 0, 0, 0):
-            image = MangaImage(src_path=src_path)
-            image.crop_manual_with_offsets(offsets=self._image_params['crop'], dest_path=dest_path)
-            image.close()
-
     def _build_http_params(self, params):
         if params is None:
             params = {}
@@ -108,14 +83,6 @@ class Base:
             return ua_storage
         return ua_params
 
-    @property
-    def chapter_id(self):
-        return self._storage.get('current_chapter', 0)
-
-    @chapter_id.setter
-    def chapter_id(self, idx):
-        self._storage['current_chapter'] = idx
-
     @classmethod
     def __normalize_chapters(cls, n, element):
         if isinstance(element, HtmlElement):
@@ -135,10 +102,6 @@ class Base:
             warning('Chapters list empty. Check %s' % self.get_url())
         return items
 
-    @property
-    def chapter(self):
-        return self._storage['chapters'][self.chapter_id]
-
     def get_current_file(self):
         return self._storage['files'][self._storage['current_file']]
 
@@ -161,11 +124,24 @@ class Base:
         # manga_name, url, directory
         pass
 
-    @property
-    def quiet(self):
-        return self.__quiet
+    def _fill_arguments(self, arguments: List[str]):
+        know_args = [
+            'login',
+            'password',
+            'language',
+            'translator',
+        ]
 
-    @quiet.setter
-    def quiet(self, val: bool):
-        self.__quiet = val
+        if self.__arguments is None:
+            self.__arguments = {}
+
+        for arg in arguments:
+            key, value = arg.split('=', 1)  # type: str, str
+            if key in know_args:
+                self.__arguments[key] = value
+
+    def arg(self, key: str) -> Optional[str]:
+        if self.__arguments is None:
+            return None
+        return self.__arguments.get(key)
 
